@@ -1,9 +1,10 @@
 from .utils import *
-from .importers import *
+# from .importers import *
 from .captcha import *
 from .client import *
 
 __all__ = [
-    'import_win_lose', 'import_ticket', 'get_uri',
+    # 'import_win_lose', 'import_ticket',
+    'get_uri',
     'get_base_url', 'captcha_solver', 'login_required', 'BaseClient'
 ]
